"use strict";
var testing_1 = require('@angular/core/testing');
var http_1 = require('@angular/http');
var session_controller_1 = require("./session.controller");
testing_1.describe('SessionController', function () {
    'use strict';
    testing_1.describe('.userSignedIn', function () {
        testing_1.it('returns true if user sis signed in', function () {
            localStorage.setItem(session_controller_1.SessionController.config.uid, 'foo@bar.com');
            testing_1.expect(session_controller_1.SessionController.userSignedIn()).toBeTruthy();
        });
    });
    testing_1.describe('.getUserUid', function () {
        testing_1.it('returns the user uid', function () {
            var userUid = 'foo@bar.com';
            localStorage.setItem(session_controller_1.SessionController.config.uid, userUid);
            testing_1.expect(session_controller_1.SessionController.getUserUid()).toBe(userUid);
        });
    });
    testing_1.describe('.setUser', function () {
        testing_1.it('sets the user headers on storage', function () {
            var headers = {
                'access-token': "Foo",
                'token-type': "Bar",
                'client': "token",
                'expiry': 'no-expiry',
                'uid': 'foo@bar.com',
                'foo': 'bar'
            };
            session_controller_1.SessionController.setUser(new http_1.Headers(headers));
            var authHeaders = session_controller_1.SessionController.getAuthHeaders();
            testing_1.expect(authHeaders['access-token']).toBe("Foo");
            testing_1.expect(authHeaders['token-type']).toBe("Bar");
            testing_1.expect(authHeaders['client']).toBe("token");
            testing_1.expect(authHeaders['expiry']).toBe('no-expiry');
            testing_1.expect(authHeaders['uid']).toBe('foo@bar.com');
            testing_1.expect(authHeaders['foo']).toBeUndefined();
        });
    });
    testing_1.describe('.removeUser', function () {
        testing_1.beforeEach(function () {
            var headers = {
                'access-token': "Foo",
                'token-type': "Bar",
                'client': "token",
                'expiry': 'no-expiry',
                'uid': 'foo@bar.com',
                'foo': 'bar'
            };
            session_controller_1.SessionController.setUser(new http_1.Headers(headers));
        });
        testing_1.it('sets the user headers on storage', function () {
            session_controller_1.SessionController.removeUser();
            var authHeaders = session_controller_1.SessionController.getAuthHeaders();
            testing_1.expect(authHeaders['access-token']).toBeNull();
            testing_1.expect(authHeaders['token-type']).toBeNull();
            testing_1.expect(authHeaders['client']).toBeNull();
            testing_1.expect(authHeaders['expiry']).toBeNull();
            testing_1.expect(authHeaders['uid']).toBeNull();
        });
    });
    testing_1.describe('.renewAccess', function () {
        testing_1.beforeEach(function () {
            var headers = {
                'access-token': "Foo",
                'token-type': "Bar",
                'client': "token",
                'expiry': 'no-expiry',
                'uid': 'foo@bar.com',
                'foo': 'bar'
            };
            session_controller_1.SessionController.setUser(new http_1.Headers(headers));
        });
        testing_1.it('renews the access', function () {
            var newHeaders = {
                'access-token': "new",
                'client': "access"
            };
            session_controller_1.SessionController.renewAccess(new http_1.Headers(newHeaders));
            testing_1.expect(session_controller_1.SessionController.getAuthHeaders()['access-token']).toBe('new');
            testing_1.expect(session_controller_1.SessionController.getAuthHeaders()['client']).toBe('access');
        });
    });
    testing_1.describe('.getAuthHeaders', function () {
        testing_1.beforeEach(function () {
            localStorage.setItem('access-token', "Foo");
            localStorage.setItem('token-type', "Bar");
            localStorage.setItem('client', "token");
            localStorage.setItem('expiry', 'no-expiry');
            localStorage.setItem('uid', 'foo@bar.com');
        });
        testing_1.it('returns the auth headers', function () {
            var authHeaders = session_controller_1.SessionController.getAuthHeaders();
            testing_1.expect(authHeaders['access-token']).toBe("Foo");
            testing_1.expect(authHeaders['token-type']).toBe("Bar");
            testing_1.expect(authHeaders['client']).toBe("token");
            testing_1.expect(authHeaders['expiry']).toBe('no-expiry');
            testing_1.expect(authHeaders['uid']).toBe('foo@bar.com');
            testing_1.expect(authHeaders['foo']).toBeUndefined();
        });
    });
});
//# sourceMappingURL=session.controller.spec.js.map